@@ -1,22 +1,20 @@
 # Surface Base Features --------------------------------------------------------
 
-#' Each half of the football field spans from the back edge of the endzone to
-#' the center of the major yard line at midfield
+#' Each half of the football field spans from the edge of the goal line nearest
+#' to midfield to the center of the major yard line at midfield
 #'
 #' @param field_length The length of the field
 #' @param field_width The width of the field
-#' @param endzone_length The length of the endzone
 #'
 #' @return A data frame of the bounding box of half a football field
 #'
 #' @keywords internal
 football_half_field <- function(field_length = 0,
-                                field_width = 0,
-                                endzone_length = 0) {
+                                field_width = 0) {
   half_field_df <- create_rectangle(
     # Using quarter-field lengths to account for feature positioning adjustment
-    x_min = -((field_length / 4) + endzone_length),
-    x_max = (field_length / 4) + endzone_length,
+    x_min = -field_length / 4,
+    x_max = field_length / 4,
     y_min = -field_width / 2,
     y_max = field_width / 2
   )
@@ -69,6 +67,8 @@ football_endzone <- function(field_width = 0, endzone_length = 0) {
 #'   the team bench area
 #' @param extra_apron_padding Any additional distance to add to the apron of the
 #'   field
+#' @param bench_shape A string of the shape of the bench. Currently, this checks
+#'   for \code{"rectangle"}
 #'
 #' @return A data frame of the bounding coordinates of the field apron
 #'
@@ -86,7 +86,8 @@ football_field_apron <- function(field_length = 0,
                                  team_bench_length_back_side = 0,
                                  team_bench_width = 0,
                                  team_bench_area_border_thickness = 0,
-                                 extra_apron_padding = 0) {
+                                 extra_apron_padding = 0,
+                                 bench_shape = "") {
   # Define the extreme values of x and y
   ext_x <- (field_length / 2) +
     endzone_length +
@@ -94,19 +95,219 @@ football_field_apron <- function(field_length = 0,
     field_border_thickness +
     extra_apron_padding
 
-  ext_y <- (field_width / 2) +
+  starting_depth <- (field_width / 2) +
     boundary_thickness +
-    field_border_thickness +
     restricted_area_width +
     coaching_box_width +
     team_bench_width +
-    extra_apron_padding
+    team_bench_area_border_thickness +
+    field_border_thickness
 
-  field_apron_df <- create_rectangle(
-    x_min = -ext_x,
-    x_max = ext_x,
-    y_min = -ext_y,
-    y_max = ext_y
+  ext_y <- starting_depth + extra_apron_padding
+
+  if (tolower(bench_shape) %in% c("rectangle", "rectangular")) {
+    m <- team_bench_width / (
+      (team_bench_length_back_side / 2) - (team_bench_length_field_side / 2)
+    )
+
+    y2 <- starting_depth + field_border_thickness
+    y1 <- starting_depth - team_bench_width - team_bench_area_border_thickness
+    x1 <- (team_bench_length_field_side / 2) +
+      team_bench_area_border_thickness +
+      field_border_thickness
+
+    outer_corner_x_dist <- (((y2 - y1) / m) + x1)
+  } else {
+    outer_corner_x_dist <- (team_bench_length_back_side / 2) +
+      team_bench_area_border_thickness +
+      (field_border_thickness / 2)
+  }
+
+  field_apron_df <- data.frame(
+    x = c(
+      # Start
+      0,
+
+      # Short edge of bench (top)
+      outer_corner_x_dist,
+
+      # Long edge of bench (top)
+      (team_bench_length_field_side / 2) +
+        team_bench_area_border_thickness +
+        field_border_thickness,
+
+      # Coaching box (top)
+      (coaching_box_length / 2) +
+        team_bench_area_border_thickness +
+        field_border_thickness,
+
+      # Restricted area (top)
+      (restricted_area_length / 2) +
+        team_bench_area_border_thickness +
+        field_border_thickness,
+
+      # Edge of field (top)
+      (field_length / 2) +
+        endzone_length +
+        boundary_thickness +
+        field_border_thickness,
+
+      # Edge of field (bottom)
+      (field_length / 2) +
+        endzone_length +
+        boundary_thickness +
+        field_border_thickness,
+
+      # Restricted area (bottom)
+      (restricted_area_length / 2) +
+        team_bench_area_border_thickness +
+        field_border_thickness,
+
+      # Coaching box (bottom)
+      (coaching_box_length / 2) +
+        team_bench_area_border_thickness +
+        field_border_thickness,
+
+      # Long edge of bench (bottom)
+      (team_bench_length_field_side / 2) +
+        team_bench_area_border_thickness +
+        field_border_thickness,
+
+      # Short edge of bench (bottom)
+      outer_corner_x_dist,
+
+      # Zero
+      0,
+
+      # Outward
+      0,
+
+      # Edge of apron (bottom)
+      ext_x,
+
+      # Edge of apron (top)
+      ext_x,
+
+      # Zero (top)
+      0,
+
+      # End
+      0
+    ),
+    y = c(
+      # Start
+      (
+        (field_width / 2) +
+          boundary_thickness +
+          restricted_area_width +
+          coaching_box_width +
+          team_bench_width +
+          team_bench_area_border_thickness +
+          field_border_thickness
+      ),
+      # Short edge of bench (top)
+      (
+        (field_width / 2) +
+          boundary_thickness +
+          restricted_area_width +
+          coaching_box_width +
+          team_bench_width +
+          team_bench_area_border_thickness +
+          field_border_thickness
+      ),
+      # Long edge of bench (top)
+      (
+        (field_width / 2) +
+          boundary_thickness +
+          restricted_area_width +
+          coaching_box_width
+      ),
+      # Coaching box (top)
+      (
+        (field_width / 2) +
+          boundary_thickness +
+          restricted_area_width
+      ),
+      # Restricted area (top)
+      (
+        (field_width / 2) +
+          boundary_thickness +
+          field_border_thickness
+      ),
+      # Edge of field (top)
+      (
+        (field_width / 2) +
+          boundary_thickness +
+          field_border_thickness
+      ),
+      # Edge of field (bottom)
+      -(
+        (field_width / 2) +
+          boundary_thickness +
+          field_border_thickness
+      ),
+      # Restricted area (bottom)
+      -(
+        (field_width / 2) +
+          boundary_thickness +
+          field_border_thickness
+      ),
+      # Coaching box (bottom)
+      -(
+        (field_width / 2) +
+          boundary_thickness +
+          restricted_area_width
+      ),
+      # Long edge of bench (bottom)
+      -(
+        (field_width / 2) +
+          boundary_thickness +
+          restricted_area_width +
+          coaching_box_width
+      ),
+      # Short edge of bench (bottom)
+      -(
+        (field_width / 2) +
+          boundary_thickness +
+          restricted_area_width +
+          coaching_box_width +
+          team_bench_width +
+          team_bench_area_border_thickness +
+          field_border_thickness
+      ),
+      # Zero
+      -(
+        (field_width / 2) +
+          boundary_thickness +
+          restricted_area_width +
+          coaching_box_width +
+          team_bench_width +
+          team_bench_area_border_thickness +
+          field_border_thickness
+      ),
+      # Outward
+      -ext_y,
+
+      # Edge of apron (bottom)
+      -ext_y,
+
+      # Edge of apron (top)
+      ext_y,
+
+      # Zero
+      ext_y,
+
+      # End
+      (
+        (field_width / 2) +
+          boundary_thickness +
+          restricted_area_width +
+          coaching_box_width +
+          team_bench_width +
+          team_bench_area_border_thickness +
+          field_border_thickness
+      )
+    )
   )
 
   return(field_apron_df)
@@ -216,13 +417,13 @@ football_field_border <- function(field_length = 0,
           (field_length / 2) +
             endzone_length +
             boundary_line_thickness +
-            team_bench_area_border_thickness
+            feature_thickness
         ),
         (
           (field_length / 2) +
             endzone_length +
             boundary_line_thickness +
-            team_bench_area_border_thickness
+            feature_thickness
         ),
         (restricted_area_length / 2) + team_bench_area_border_thickness,
         (restricted_area_length / 2) + team_bench_area_border_thickness
@@ -387,7 +588,7 @@ football_field_border <- function(field_length = 0,
 #' @param bench_shape A string of the shape of the bench. Currently, this checks
 #'   for \code{"rectangle"}
 #'
-#' @return A data frame of the bounding box of the field border
+#' @return A data frame of the bounding box of the field border's outline
 #'
 #' @keywords internal
 football_field_border_outline <- function(field_length = 0,
@@ -817,6 +1018,46 @@ football_field_border_outline <- function(field_length = 0,
   return(field_border_outline_df)
 }
 
+#' The field border (see [football_field_border()]) may have a different color
+#' along the red zone than it does along the rest of the field. This is not
+#' always the case, but the feature is provided for convenience
+#'
+#' @param feature_thickness The thickness of the field border
+#'
+#' @return A data frame of the bounding box of the red zone border
+#'
+#' @keywords internal
+football_red_zone_border <- function(feature_thickness = 0) {
+  red_zone_border_df <- create_rectangle(
+    x_min = 0,
+    x_max = 20,
+    y_min = 0,
+    y_max = feature_thickness
+  )
+
+  return(red_zone_border_df)
+}
+
+#' The outline of the [football_red_zone_border()] may be a different color than
+#' the rest of the field border. This is not always the case, but the feature is
+#' provided for convenience
+#'
+#' @param feature_thickness The thickness of the field border's outline
+#'
+#' @return A data frame of the bounding box of the red zone border's outline
+#'
+#' @keywords internal
+football_red_zone_border_outline <- function(feature_thickness = 0) {
+  red_zone_border_outline_df <- create_rectangle(
+    x_min = 0,
+    x_max = 20,
+    y_min = 0,
+    y_max = feature_thickness
+  )
+
+  return(red_zone_border_outline_df)
+}
+
 
 
 
