@@ -112,24 +112,26 @@ hockey_features_set_colors <- function(plot_background = NULL,
 #'   The possible display ranges are:
 #'   \describe{
 #'     \item{\code{"full"}}{The full ice surface. This is the default}
-#'     \item{\code{"offense"}}{The TV-right half of the ice surface}
-#'     \item{\code{"offence"}}{The TV-right half of the ice surface}
-#'     \item{\code{"defense"}}{The TV-left half of the ice surface}
-#'     \item{\code{"defence"}}{The TV-left half of the ice surface}
-#'     \item{\code{"ozone"}}{The TV-right zone of the ice surface}
-#'     \item{\code{"offensive_zone"}}{The TV-right zone of the ice surface}
-#'     \item{\code{"offensive zone"}}{The TV-right zone of the ice surface}
-#'     \item{\code{"attacking_zone"}}{The TV-right zone of the ice surface}
-#'     \item{\code{"attacking zone"}}{The TV-right zone of the ice surface}
-#'     \item{\code{"dzone"}}{The TV-left zone of the ice surface}
-#'     \item{\code{"defensive_zone"}}{The TV-left zone of the ice surface}
-#'     \item{\code{"defensive zone"}}{The TV-left zone of the ice surface}
-#'     \item{\code{"defending_zone"}}{The TV-left zone of the ice surface}
-#'     \item{\code{"defending zone"}}{The TV-left zone of the ice surface}
-#'     \item{\code{"nzone"}}{The middle zone of the ice surface}
-#'     \item{\code{"neutral"}}{The middle zone of the ice surface}
-#'     \item{\code{"neutral_zone"}}{The middle zone of the ice surface}
-#'     \item{\code{"neutral zone"}}{The middle zone of the ice surface}
+#'     \item{\code{"in_bounds_only"}}{The full in-bounds area of the rink}
+#'     \item{\code{"in bounds only"}}{The full in-bounds area of the rink}
+#'     \item{\code{"offense"}}{The TV-right half of the rink}
+#'     \item{\code{"offence"}}{The TV-right half of the rink}
+#'     \item{\code{"defense"}}{The TV-left half of the rink}
+#'     \item{\code{"defence"}}{The TV-left half of the rink}
+#'     \item{\code{"ozone"}}{The TV-right zone of the rink}
+#'     \item{\code{"offensive_zone"}}{The TV-right zone of the rink}
+#'     \item{\code{"offensive zone"}}{The TV-right zone of the rink}
+#'     \item{\code{"attacking_zone"}}{The TV-right zone of the rink}
+#'     \item{\code{"attacking zone"}}{The TV-right zone of the rink}
+#'     \item{\code{"dzone"}}{The TV-left zone of the rink}
+#'     \item{\code{"defensive_zone"}}{The TV-left zone of the rink}
+#'     \item{\code{"defensive zone"}}{The TV-left zone of the rink}
+#'     \item{\code{"defending_zone"}}{The TV-left zone of the rink}
+#'     \item{\code{"defending zone"}}{The TV-left zone of the rink}
+#'     \item{\code{"nzone"}}{The middle zone of the rink}
+#'     \item{\code{"neutral"}}{The middle zone of the rink}
+#'     \item{\code{"neutral_zone"}}{The middle zone of the rink}
+#'     \item{\code{"neutral zone"}}{The middle zone of the rink}
 #'   }
 #' @param rink_updates A list of updates to the rink's parameters. These will
 #'   overwrite the parameters of the league
@@ -876,6 +878,22 @@ geom_hockey <- function(league,
     xlims <- switch(tolower(display_range),
       # Full surface
       "full" = c(-half_rink_length, half_rink_length),
+      "in_bounds_only" = c(
+        -(
+          ((rink_params$rink_length %or% 0) / 2) +
+            (rink_params$board_thickness %or% 0)
+        ),
+        ((rink_params$rink_length %or% 0) / 2) +
+          (rink_params$board_thickness %or% 0)
+      ),
+      "in bounds only" = c(
+        -(
+          ((rink_params$rink_length %or% 0) / 2) +
+            (rink_params$board_thickness %or% 0)
+        ),
+        ((rink_params$rink_length %or% 0) / 2) +
+          (rink_params$board_thickness %or% 0)
+      ),
 
       # Half-rink plots
       "offense" = c(0, half_rink_length),
@@ -965,6 +983,22 @@ geom_hockey <- function(league,
     ylims <- switch(tolower(display_range),
       # Full surface
       "full" = c(-(half_rink_width), half_rink_width),
+      "in_bounds_only" = c(
+        -(
+          ((rink_params$rink_width %or% 0) / 2) +
+            (rink_params$board_thickness %or% 0)
+        ),
+        ((rink_params$rink_width %or% 0) / 2) +
+          (rink_params$board_thickness %or% 0)
+      ),
+      "in bounds only" = c(
+        -(
+          ((rink_params$rink_width %or% 0) / 2) +
+            (rink_params$board_thickness %or% 0)
+        ),
+        ((rink_params$rink_width %or% 0) / 2) +
+          (rink_params$board_thickness %or% 0)
+      ),
 
       # Half-rink plots
       "offense" = c(-half_rink_width, half_rink_width),
@@ -1021,7 +1055,8 @@ geom_hockey <- function(league,
   rink_plot <- rink_plot +
     ggplot2::coord_fixed(
       xlim = xlims,
-      ylim = ylims
+      ylim = ylims,
+      expand = FALSE
     )
 
   # Return the ggplot2 instance
