@@ -80,6 +80,8 @@ tennis_features_set_colors <- function(plot_background = NULL,
 #'   The possible display ranges are:
 #'   \describe{
 #'     \item{\code{"full"}}{The full court. This is the default}
+#'     \item{\code{"in_bounds_only"}}{The full in-bounds area of the court}
+#'     \item{\code{"in bounds only"}}{The full in-bounds area of the court}
 #'     \item{\code{"serve"}}{The serving half of the court}
 #'     \item{\code{"serving"}}{The serving half of the court}
 #'     \item{\code{"servicehalf"}}{The serving half of the court}
@@ -477,6 +479,22 @@ geom_tennis <- function(league,
     xlims <- switch(tolower(display_range),
                     # Full surface
                     "full" = c(-half_court_length, half_court_length),
+                    "in_bounds_only" = c(
+                      -(
+                        ((court_params$court_length %or% 0) / 2) +
+                          (court_params$line_thickness %or% 0)
+                      ),
+                      ((court_params$court_length %or% 0) / 2) +
+                        (court_params$line_thickness %or% 0)
+                    ),
+                    "in bounds only" = c(
+                      -(
+                        ((court_params$court_length %or% 0) / 2) +
+                          (court_params$line_thickness %or% 0)
+                      ),
+                      ((court_params$court_length %or% 0) / 2) +
+                        (court_params$line_thickness %or% 0)
+                    ),
 
                     # Service half
                     "serve" = c(-half_court_length, 1.5),
@@ -510,6 +528,22 @@ geom_tennis <- function(league,
     ylims <- switch(tolower(display_range),
                     # Full surface
                     "full" = c(-half_court_width, half_court_width),
+                    "in_bounds_only" = c(
+                      -(
+                        ((court_params$doubles_width %or% 0) / 2) +
+                          (court_params$line_thickness %or% 0)
+                      ),
+                      ((court_params$doubles_width %or% 0) / 2) +
+                        (court_params$line_thickness %or% 0)
+                    ),
+                    "in bounds only" = c(
+                      -(
+                        ((court_params$doubles_width %or% 0) / 2) +
+                          (court_params$line_thickness %or% 0)
+                      ),
+                      ((court_params$doubles_width %or% 0) / 2) +
+                        (court_params$line_thickness %or% 0)
+                    ),
 
                     # Service half
                     "serve" = c(-half_court_width, half_court_width),
@@ -560,7 +594,8 @@ geom_tennis <- function(league,
   court_plot <- court_plot +
     ggplot2::coord_fixed(
       xlim = xlims,
-      ylim = ylims
+      ylim = ylims,
+      expand = FALSE
     )
 
   # Return the ggplot2 instance
